import { __decorate, __metadata } from 'tslib';
import { Prop, Component } from 'vue-property-decorator';
import BaseComponent from '../BaseComponent.js';
import { getStyles } from './ActivityItem.styles.js';
import { getClassNames } from './ActivityItem.classNames.js';
import { PersonaSize } from '../Persona/Persona.types.js';
import { PersonaCoin } from '../Persona/PersonaCoin/index.js';

let ActivityItem = class ActivityItem extends BaseComponent {
  constructor() {
    super(...arguments);
    this.PersonaSize = PersonaSize;
  }

  get personaStyle() {
    if (!this.isCompact) return {};
    return {
      display: 'inline-block',
      width: '10px',
      minWidth: '10px',
      overflow: 'visible'
    };
  }

  get personasToRender() {
    const personaLimit = this.isCompact ? 3 : 4;
    return this.activityPersonas.filter((person, index) => index < personaLimit);
  }

  get classNames() {
    const {
      styles,
      theme,
      className,
      activityPersonas,
      animateBeaconSignal,
      beaconColorOne,
      beaconColorTwo,
      isCompact
    } = this;
    return getClassNames(getStyles(theme, styles, animateBeaconSignal, beaconColorOne, beaconColorTwo, isCompact), className, activityPersonas, isCompact);
  }

  render() {
    const h = arguments[0];
    const {
      classNames,
      activityPersonas,
      animateBeaconSignal,
      isCompact,
      personasToRender,
      personaStyle
    } = this;
    return h("div", {
      "class": classNames.root
    }, [(activityPersonas || this.$slots.icon) && h("div", {
      "class": classNames.activityTypeIcon
    }, [animateBeaconSignal && isCompact && h("div", {
      "class": classNames.pulsingBeacon
    }), activityPersonas.length > 0 && h("div", {
      "class": classNames.personaContainer
    }, [personasToRender.map((person, index) => h(PersonaCoin, {
      "props": { ...person
      },
      "key": person.key || index,
      "class": classNames.activityPersona,
      "attrs": {
        "size": activityPersonas.length > 1 || isCompact ? PersonaSize.size16 : PersonaSize.size32
      },
      "style": personaStyle
    }))]), this.$slots.icon]), h("div", {
      "class": classNames.activityContent
    }, [this.$slots.activityDescription && h("span", {
      "class": classNames.activityText
    }, [this.$slots.activityDescription]), !isCompact && this.$slots.comments && h("div", {
      "class": classNames.commentText
    }, [this.$slots.comments]), !isCompact && this.$slots.timeStamp && h("div", {
      "class": classNames.timeStamp
    }, [this.$slots.timeStamp])])]);
  }

};

__decorate([Prop({
  type: Array,
  default: () => []
}), __metadata("design:type", Array)], ActivityItem.prototype, "activityPersonas", void 0);

__decorate([Prop({
  type: Boolean,
  default: false
}), __metadata("design:type", Boolean)], ActivityItem.prototype, "animateBeaconSignal", void 0);

__decorate([Prop({
  type: String,
  default: null
}), __metadata("design:type", String)], ActivityItem.prototype, "beaconColorOne", void 0);

__decorate([Prop({
  type: String,
  default: null
}), __metadata("design:type", String)], ActivityItem.prototype, "beaconColorTwo", void 0);

__decorate([Prop({
  type: Boolean,
  default: false
}), __metadata("design:type", Boolean)], ActivityItem.prototype, "isCompact", void 0);

ActivityItem = __decorate([Component({
  components: {
    PersonaCoin
  }
})], ActivityItem);

export { ActivityItem };
