import { __decorate, __metadata } from 'tslib';
import { Prop, Component } from 'vue-property-decorator';
import { classNamesFunction, css } from '@uifabric-vue/utilities';
import BaseComponent from '../BaseComponent.js';
import { DirectionalHint } from '../../common/DirectionalHint.js';
import { Callout } from '../Callout/Callout.js';
import { ContextualMenuItem } from './ContextualMenuItem.js';

const getClassNames = classNamesFunction({
  disableCaching: true
});
let ContextualMenuBase = class ContextualMenuBase extends BaseComponent {
  created() {
    console.log(this.target);
  }

  get classNames() {
    const {
      styles,
      theme,
      className
    } = this;
    return getClassNames(styles, {
      theme,
      className
    });
  }

  get contextMenuStyle() {
    const targetBoundingRect = this.target.getBoundingClientRect();
    const targetWidth = targetBoundingRect.width - 2;
    /* Accounts for 1px border */

    return {
      width: `${targetWidth}px`
    };
  }

  render() {
    const h = arguments[0];
    const {
      target,
      directionalHint,
      calloutProps,
      onDismiss,
      contextMenuStyle,
      classNames,
      items
    } = this;
    return h(Callout, {
      "attrs": {
        "target": target,
        "directional-hint": directionalHint,
        "is-beak-visible": false
      },
      "class": css('ms-ContextualMenu-Callout', calloutProps && calloutProps.className),
      "on": {
        "dismiss": onDismiss
      }
    }, [h("div", {
      "style": contextMenuStyle,
      "class": classNames.container
    }, [h("div", {
      "class": classNames.root
    }, [h("ul", {
      "class": classNames.list,
      "attrs": {
        "role": "menu"
      }
    }, [items.map((item, index) => h("li", {
      "key": item.key || index,
      "class": classNames.item
    }, [h(ContextualMenuItem, {
      "attrs": {
        "item": item,
        "prop-class-names": classNames
      }
    })]))])])])]);
  }

};

__decorate([Prop(), __metadata("design:type", HTMLElement)], ContextualMenuBase.prototype, "target", void 0);

__decorate([Prop({
  type: Object,
  default: () => {}
}), __metadata("design:type", Object)], ContextualMenuBase.prototype, "calloutProps", void 0);

__decorate([Prop({
  type: Number,
  default: DirectionalHint.bottomAutoEdge
}), __metadata("design:type", Boolean)], ContextualMenuBase.prototype, "directionalHint", void 0);

__decorate([Prop({
  type: Function,
  default: () => null
}), __metadata("design:type", Function)], ContextualMenuBase.prototype, "onDismiss", void 0);

__decorate([Prop({
  type: Array,
  default: () => []
}), __metadata("design:type", Array)], ContextualMenuBase.prototype, "items", void 0);

ContextualMenuBase = __decorate([Component({
  components: {
    Callout,
    ContextualMenuItem
  }
})], ContextualMenuBase);

export { ContextualMenuBase };
