import { __decorate, __metadata } from 'tslib';
import { Prop, Component } from 'vue-property-decorator';
import { classNamesFunction } from '@uifabric-vue/utilities';
import BaseComponent from '../BaseComponent.js';
import { Icon } from '../Icon/index.js';
import { Callout } from '../Callout/Callout.js';
import { ActionButton } from '../Button/ActionButton/ActionButton.js';
import { Label } from '../Label/index.js';
import { Checkbox } from '../Checkbox/index.js';

const getClassNames = classNamesFunction();
let DropdownBase = class DropdownBase extends BaseComponent {
  constructor() {
    super(...arguments);
    this.isOpen = false;
    this.calloutRenderEdge = null;
  }

  created() {
    this.options.forEach(option => {
      this.$set(option, 'isItemSelected', false);
    });
  }

  get classNames() {
    const {
      theme,
      className,
      errorMessage,
      label,
      required,
      disabled,
      panelProps,
      calloutProps
    } = this;
    const {
      isOpen,
      calloutRenderEdge
    } = this;
    const selectedOptions = this.selectedOptions;
    return getClassNames(this.styles, {
      theme,
      className,
      hasError: !!(errorMessage && errorMessage.length > 0),
      hasLabel: !!label,
      isOpen,
      required,
      disabled,
      isRenderingPlaceholder: !selectedOptions.length,
      panelClassName: panelProps ? panelProps.className : undefined,
      calloutClassName: calloutProps ? calloutProps.className : undefined,
      calloutRenderEdge: calloutRenderEdge
    });
  }

  get multiSelectItemStyles() {
    return this.classNames.subComponentStyles ? this.classNames.subComponentStyles.multiSelectItem : undefined;
  }

  get hasErrorMessage() {
    return this.errorMessage && this.errorMessage.length > 0;
  }

  select(option) {
    if (option.disabled) return;
    const index = this.selectedOptions.findIndex(o => o.key === option.key);

    if (index > -1) {
      this.selectedOptions[index].isItemSelected = false;
      this.selectedOptions.splice(index, 1);
    } else {
      if (!this.multiSelect) {
        this.selectedOptions.splice(0, this.selectedOptions.length);
        this.isOpen = false;
      }

      option.isItemSelected = true;
      this.selectedOptions.push(option);
    }
  }

  onPositioned(positions) {
    if (!this.calloutRenderEdge || this.calloutRenderEdge !== positions.targetEdge) {
      this.calloutRenderEdge = positions.targetEdge;
    }
  }

  render() {
    const h = arguments[0];
    const {
      classNames,
      label,
      selectedOptions,
      multiSelect,
      multiSelectDelimiter,
      placeholder,
      isOpen,
      dropdownWidth,
      options,
      hasErrorMessage,
      errorMessage,
      required,
      disabled
    } = this;
    const OptionComponent = multiSelect ? Checkbox : ActionButton;
    return h("div", {
      "class": classNames.root
    }, [h(Label, {
      "class": classNames.label,
      "attrs": {
        "required": required,
        "disabled": disabled
      }
    }, [label]), h("div", {
      "ref": "dropdown",
      "class": classNames.dropdown,
      "on": {
        "click": () => this.isOpen = true
      }
    }, [h("span", {
      "class": classNames.title
    }, [selectedOptions.length ? selectedOptions.map(i => i.text).join(multiSelectDelimiter) : placeholder]), h("span", {
      "class": classNames.caretDownWrapper
    }, [h(Icon, {
      "class": classNames.caretDown,
      "attrs": {
        "icon-name": "ChevronDown"
      }
    })])]), isOpen && h("div", [h(Callout, {
      "attrs": {
        "target": this.$refs.dropdown,
        "is-beak-visible": false,
        "callout-width": dropdownWidth || (this.$refs.dropdown ? this.$refs.dropdown.clientWidth : 0)
      },
      "on": {
        "dismiss": () => this.isOpen = false,
        "positioned": this.onPositioned
      }
    }, [h("div", {
      "class": classNames.dropdownItemsWrapper,
      "attrs": {
        "tabindex": 0
      }
    }, [options.map((option, index) => h(OptionComponent, {
      "key": index,
      "class": option.hidden ? classNames.dropdownItemHidden : option.isItemSelected && option.disabled === true ? classNames.dropdownItemSelectedAndDisabled : option.isItemSelected ? classNames.dropdownItemSelected : option.disabled === true ? classNames.dropdownItemDisabled : classNames.dropdownItem,
      "attrs": {
        "disabled": option.disabled,
        "title": option.text,
        "checked": option.isItemSelected,
        "styles": multiSelect ? this.multiSelectItemStyles : null,
        "role": option
      },
      "nativeOn": {
        "click": () => !multiSelect && this.select(option)
      },
      "on": {
        "input": () => multiSelect && this.select(option)
      }
    }, [option.text]))])])]), hasErrorMessage && h("div", {
      "attrs": {
        "role": "alert"
      },
      "class": classNames.errorMessage
    }, [errorMessage])]);
  }

};

__decorate([Prop({
  type: Array,
  required: true
}), __metadata("design:type", Array)], DropdownBase.prototype, "options", void 0);

__decorate([Prop({
  type: Array,
  default: () => []
}), __metadata("design:type", Array)], DropdownBase.prototype, "selectedOptions", void 0);

__decorate([Prop({
  type: String,
  default: ''
}), __metadata("design:type", String)], DropdownBase.prototype, "label", void 0);

__decorate([Prop({
  type: String,
  default: ''
}), __metadata("design:type", String)], DropdownBase.prototype, "placeholder", void 0);

__decorate([Prop({
  type: String,
  default: ''
}), __metadata("design:type", String)], DropdownBase.prototype, "errorMessage", void 0);

__decorate([Prop({
  type: Boolean,
  default: false
}), __metadata("design:type", Boolean)], DropdownBase.prototype, "required", void 0);

__decorate([Prop({
  type: Boolean,
  default: false
}), __metadata("design:type", Boolean)], DropdownBase.prototype, "disabled", void 0);

__decorate([Prop({
  type: Boolean,
  default: false
}), __metadata("design:type", Boolean)], DropdownBase.prototype, "multiSelect", void 0);

__decorate([Prop({
  type: String,
  default: ', '
}), __metadata("design:type", String)], DropdownBase.prototype, "multiSelectDelimiter", void 0);

__decorate([Prop({
  type: Number,
  default: 0
}), __metadata("design:type", Number)], DropdownBase.prototype, "dropdownWidth", void 0);

__decorate([Prop({
  type: Object,
  default: () => {}
}), __metadata("design:type", Object)], DropdownBase.prototype, "panelProps", void 0);

__decorate([Prop({
  type: Object,
  default: () => {}
}), __metadata("design:type", Object)], DropdownBase.prototype, "calloutProps", void 0);

DropdownBase = __decorate([Component({
  components: {
    Callout,
    ActionButton,
    Checkbox,
    Icon,
    Label
  }
})], DropdownBase);

export { DropdownBase };
