import { __decorate, __metadata } from 'tslib';
import { Prop, Component } from 'vue-property-decorator';
import { memoizeFunction, css } from '@uifabric-vue/utilities';
import { getIcon } from '@uifabric/styling';
import StatelessComponent from '../StatelessComponent.js';
import { MS_ICON, classNames } from './Icon.styles.js';

const getIconContent = memoizeFunction(iconName => {
  const {
    code,
    subset
  } = getIcon(iconName) || {
    subset: {},
    code: undefined
  };

  if (!code) {
    return null;
  }

  return {
    children: code,
    iconClassName: subset.className,
    fontFamily: subset.fontFace && subset.fontFace.fontFamily
  };
}, undefined, // @ts-ignore
true);
let FontIcon = class FontIcon extends StatelessComponent {
  render(h, ctx) {
    const className = ctx.props.className || ctx.data.class;
    const {
      iconName,
      style = {}
    } = ctx.props;
    const iconContent = getIconContent(iconName) || {};
    const children = iconContent.children;
    const {
      iconClassName,
      fontFamily
    } = iconContent;
    return h("i", {
      "class": css(MS_ICON, classNames.root, iconClassName, !iconName && classNames.placeholder, className),
      "style": {
        fontFamily,
        ...style
      }
    }, [typeof children === 'function' ? children(h) : children]);
  }

};

__decorate([Prop({
  type: String,
  default: ''
}), __metadata("design:type", String)], FontIcon.prototype, "iconName", void 0);

FontIcon = __decorate([Component], FontIcon);

export { FontIcon, getIconContent };
