import { __decorate, __metadata } from 'tslib';
import { Prop, Component } from 'vue-property-decorator';
import { classNamesFunction } from '@uifabric-vue/utilities';
import BaseComponent from '../BaseComponent.js';
import _mergeJSXProps from '@vue/babel-helper-vue-jsx-merge-props';
import { ImageLoadState, ImageCoverStyle, ImageFit } from './Image.types.js';

const getClassNames = classNamesFunction();
let ImageBase = class ImageBase extends BaseComponent {
  constructor() {
    super(...arguments);
    this.loadState = ImageLoadState.notLoaded;
  }

  render() {
    const h = arguments[0];
    const {
      classNames,
      src,
      alt,
      width,
      height
    } = this;
    return h("div", {
      "class": classNames.root,
      "style": {
        width: width + 'px',
        height: height + 'px'
      }
    }, [h("img", _mergeJSXProps([{}, this.$attrs, {
      "class": classNames.image,
      "attrs": {
        "src": src,
        "alt": alt
      },
      "on": {
        "load": this.onImageLoaded,
        "error": this.onImageError
      }
    }]))]);
  }

  get classNames() {
    const {
      styles,
      loadState,
      coverStyle,
      imageFit,
      theme,
      className,
      width,
      height,
      maximizeFrame,
      shouldFadeIn,
      shouldStartVisible
    } = this;
    return getClassNames(styles, {
      theme,
      className,
      width,
      height,
      maximizeFrame,
      shouldFadeIn,
      shouldStartVisible,
      isLoaded: loadState === ImageLoadState.loaded || loadState === ImageLoadState.notLoaded && shouldStartVisible,
      isLandscape: coverStyle === ImageCoverStyle.landscape,
      isCenter: imageFit === ImageFit.center,
      isCenterContain: imageFit === ImageFit.centerContain,
      isCenterCover: imageFit === ImageFit.centerCover,
      isContain: imageFit === ImageFit.contain,
      isCover: imageFit === ImageFit.cover,
      isNone: imageFit === ImageFit.none,
      isError: loadState === ImageLoadState.error,
      isNotImageFit: imageFit == null
    });
  }

  onImageLoaded() {
    this.loadState = ImageLoadState.loaded;
  }

  onImageError() {
    this.loadState = ImageLoadState.error;
  }

};
ImageBase.svgRegex = /\.svg$/i;

__decorate([Prop({
  type: String,
  required: true
}), __metadata("design:type", String)], ImageBase.prototype, "src", void 0);

__decorate([Prop({
  type: String,
  default: ''
}), __metadata("design:type", String)], ImageBase.prototype, "alt", void 0);

__decorate([Prop({
  type: [String, Number],
  default: ''
}), __metadata("design:type", Object)], ImageBase.prototype, "width", void 0);

__decorate([Prop({
  type: [String, Number],
  default: ''
}), __metadata("design:type", Object)], ImageBase.prototype, "height", void 0);

__decorate([Prop({
  type: Number,
  default: null
}), __metadata("design:type", Number)], ImageBase.prototype, "imageFit", void 0);

__decorate([Prop({
  type: Boolean,
  default: null
}), __metadata("design:type", Boolean)], ImageBase.prototype, "maximizeFrame", void 0);

__decorate([Prop({
  type: Boolean,
  default: true
}), __metadata("design:type", Boolean)], ImageBase.prototype, "shouldFadeIn", void 0);

__decorate([Prop({
  type: Boolean,
  default: null
}), __metadata("design:type", Boolean)], ImageBase.prototype, "shouldStartVisible", void 0);

__decorate([Prop({
  type: Number,
  default: ImageCoverStyle.portrait
}), __metadata("design:type", Number)], ImageBase.prototype, "coverStyle", void 0);

ImageBase = __decorate([Component({
  inheritAttrs: false
})], ImageBase);

export { ImageBase };
