import { __decorate, __metadata } from 'tslib';
import { Prop, Component } from 'vue-property-decorator';
import { classNamesFunction } from '@uifabric-vue/utilities';
import BaseComponent from '../BaseComponent.js';
import { MountingPortal } from 'portal-vue';
import { registerLayer, unregisterLayer } from './Layer.notification.js';
import { getStyles } from './Layer.styles.js';

const getClassNames = classNamesFunction();
let LayerBase = class LayerBase extends BaseComponent {
  constructor() {
    super(...arguments);
    this.hasTarget = false;
  }

  get classNames() {
    const {
      className,
      theme
    } = this;
    return getClassNames(getStyles, {
      theme,
      className,
      isNotHost: !this.hostId
    });
  }

  mounted() {
    this.createElement();

    if (this.hostId) {
      registerLayer(this.hostId, this.createElement);
    }
  }

  beforeDestroy() {

    if (this.hostId) {
      unregisterLayer(this.hostId, this.createElement);
    }
  }

  createElement() {
    const doc = this.$el.ownerDocument;
    const host = this.getHost();

    if (!doc || !host) {
      this.hasTarget = false;
      return;
    }

    this.hasTarget = true;
  }

  getHost() {
    const doc = this.$el.ownerDocument;

    if (!doc) {
      return undefined;
    }

    if (this.hostId) {
      return doc.getElementById(this.hostId);
    } else {
      return  doc.body;
    }
  }

  render() {
    const h = arguments[0];
    if (!this.hasTarget) return;
    const {
      classNames,
      hostId,
      append
    } = this;
    return h(MountingPortal, {
      "attrs": {
        "mount-to": hostId ? `#${hostId}` : 'body',
        "append": append
      }
    }, [h("div", {
      "class": classNames.root
    }, [h("div", {
      "class": classNames.content
    }, [this.$slots.default])])]);
  }

};

__decorate([Prop({
  type: String,
  default: null
}), __metadata("design:type", String)], LayerBase.prototype, "hostId", void 0);

__decorate([Prop({
  type: Boolean,
  default: true
}), __metadata("design:type", Boolean)], LayerBase.prototype, "append", void 0);

LayerBase = __decorate([Component], LayerBase);

export { LayerBase };
