import { __decorate, __metadata } from 'tslib';
import { Prop, Watch, Component } from 'vue-property-decorator';
import { classNamesFunction } from '@uifabric-vue/utilities';
import BaseComponent from '../BaseComponent.js';
import { Icon } from '../Icon/index.js';
import { IconButton } from '../Button/IconButton/IconButton.js';
import { MessageBarType } from './MessageBar.types.js';

const getClassNames = classNamesFunction();
const ICON_MAP = {
  [MessageBarType.info]: 'Info',
  [MessageBarType.warning]: 'Info',
  [MessageBarType.error]: 'ErrorBadge',
  [MessageBarType.blocked]: 'Blocked2',
  [MessageBarType.severeWarning]: 'Warning',
  [MessageBarType.success]: 'Completed'
};
let MessageBarBase = class MessageBarBase extends BaseComponent {
  constructor() {
    super(...arguments);
    this.state = {
      expandSingleLine: this.expandSingleLine
    };
  }

  get classNames() {
    const {
      theme,
      className,
      messageBarType,
      actions,
      truncated,
      isMultiline
    } = this;
    const {
      expandSingleLine
    } = this.state;
    return getClassNames(this.styles, {
      theme,
      messageBarType: messageBarType || MessageBarType.info,
      onDismiss: this.$listeners.dismiss !== undefined,
      actions: actions !== undefined,
      truncated: truncated,
      isMultiline: isMultiline,
      expandSingleLine: expandSingleLine,
      className
    });
  }

  onExpandSingleLine(value) {
    this.state.expandSingleLine = value;
  }

  onClick() {
    this.state.expandSingleLine = !this.state.expandSingleLine;
  }

  render() {
    const h = arguments[0];
    const {
      theme,
      classNames,
      messageBarType,
      actions,
      truncated,
      isMultiline
    } = this;
    return h("div", {
      "style": {
        background: theme.semanticColors.bodyBackground
      }
    }, [h("div", {
      "class": classNames.root
    }, [h("div", {
      "class": classNames.content
    }, [h("div", {
      "class": classNames.iconContainer
    }, [h(Icon, {
      "class": classNames.icon,
      "attrs": {
        "icon-name": ICON_MAP[messageBarType]
      }
    })]), h("div", {
      "class": classNames.text,
      "attrs": {
        "role": "status"
      }
    }, [h("span", {
      "class": classNames.innerText
    }, [h("span", [this.$slots.default])])]), !actions && truncated && h("div", {
      "class": classNames.expandSingleLine
    }, [h(IconButton, {
      "class": classNames.expand,
      "attrs": {
        "icon-props": {
          iconName: this.state.expandSingleLine ? 'DoubleChevronUp' : 'DoubleChevronDown'
        }
      },
      "nativeOn": {
        "click": this.onClick
      }
    })]), !isMultiline && this.$slots.actions && h("div", {
      "class": classNames.actions
    }, [this.$slots.actions]), this.$listeners.dismiss && isMultiline && h(IconButton, {
      "class": classNames.dismissal,
      "attrs": {
        "icon-props": {
          iconName: 'Clear'
        }
      }
    }), this.$listeners.dismiss && !isMultiline && h("div", {
      "class": classNames.dismissSingleLine
    }, [h(IconButton, {
      "class": classNames.dismissal,
      "attrs": {
        "icon-props": {
          iconName: 'Clear'
        }
      }
    })])]), isMultiline && this.$slots.actions && h("div", {
      "class": classNames.actions
    }, [this.$slots.actions])])]);
  }

};

__decorate([Prop({
  type: Number,
  default: MessageBarType.info
}), __metadata("design:type", Number)], MessageBarBase.prototype, "messageBarType", void 0);

__decorate([Prop({
  type: Boolean,
  default: true
}), __metadata("design:type", Boolean)], MessageBarBase.prototype, "isMultiline", void 0);

__decorate([Prop({
  type: Boolean,
  default: false
}), __metadata("design:type", Boolean)], MessageBarBase.prototype, "actions", void 0);

__decorate([Prop({
  type: Boolean,
  default: false
}), __metadata("design:type", Boolean)], MessageBarBase.prototype, "truncated", void 0);

__decorate([Prop({
  type: Boolean,
  default: true
}), __metadata("design:type", Boolean)], MessageBarBase.prototype, "expandSingleLine", void 0);

__decorate([Watch('expandSingleLine'), __metadata("design:type", Function), __metadata("design:paramtypes", [Boolean]), __metadata("design:returntype", void 0)], MessageBarBase.prototype, "onExpandSingleLine", null);

MessageBarBase = __decorate([Component({
  components: {
    Icon,
    IconButton
  }
})], MessageBarBase);

export { MessageBarBase };
