import { __decorate, __metadata } from 'tslib';
import { Prop, Watch, Component } from 'vue-property-decorator';
import { classNamesFunction } from '@uifabric-vue/utilities';
import BaseComponent from '../BaseComponent.js';
import _mergeJSXProps from '@vue/babel-helper-vue-jsx-merge-props';
import { Icon } from '../Icon/index.js';
import { Layer } from '../Layer/Layer.js';
import { DirectionalHint } from '../../common/DirectionalHint.js';
import { Overlay } from '../Overlay/Overlay.js';
import { ResponsiveMode } from '../../utilities/responsiveMode.js';
import { Popup } from '../Popup/Popup.js';

const getClassNames = classNamesFunction();
const DefaultLayerProps = {
  eventBubblingEnabled: false
};
let ModalBase = class ModalBase extends BaseComponent {
  constructor() {
    super(...arguments);
    this.internalIsOpen = false;
    this.isVisible = false;
    this.isVisibleClose = false;
    this.hasBeenOpened = false;
    this.modalRectangleTop = 0;
    this.isModalMenuOpen = false;
    this.isInKeyboardMoveMode = false;
    this.x = 0;
    this.y = 0;
    this.lastSetX = 0;
    this.lastSetY = 0;
    this.responsiveMode = ResponsiveMode.large;
  }

  onIsOpenChanged(newVal) {
    if (newVal) this.isVisible = true;
  }

  get classNames() {
    const {
      theme,
      styles,
      className,
      layerProps,
      containerClassName,
      scrollableContentClassName,
      isVisible,
      hasBeenOpened,
      modalRectangleTop,
      topOffsetFixed,
      isModeless,
      dragOptions,
      isOpen
    } = this;
    const layerClassName = layerProps == null ? '' : layerProps.className;
    return getClassNames(styles, {
      theme: theme,
      className,
      containerClassName,
      scrollableContentClassName,
      isOpen,
      isVisible,
      hasBeenOpened,
      modalRectangleTop,
      topOffsetFixed,
      isModeless,
      layerClassName,
      isDefaultDragHandle: dragOptions && !dragOptions.dragHandleSelector
    });
  }

  onModalContextMenuClose() {
    this.isModalMenuOpen = false;
  }

  onModalClose() {
    this.isModalMenuOpen = false;
    this.isInKeyboardMoveMode = false;
    this.isOpen = false; // TODO
  }

  onEnterKeyboardMoveMode() {
    this.lastSetX = this.x;
    this.lastSetY = this.y;
    this.isInKeyboardMoveMode = true;
    this.isModalMenuOpen = true; // TODO
    // this._events.on(window, 'keydown', this._onKeyDown, true /* useCapture */);
  }

  _onDragStart() {
    this.isModalMenuOpen = false;
    this.isInKeyboardMoveMode = false;
  }

  _onDrag(_, ui) {
    this.x += ui.delta.x;
    this.y += ui.delta.y;
  }

  _onDragStop() {// this.focus()
  }

  onDismiss(ev) {
    this.$emit('dismiss', ev);
  }

  render() {
    const h = arguments[0];
    const {
      dragOptions,
      isInKeyboardMoveMode,
      classNames,
      isOpen,
      responsiveMode,
      isModeless,
      layerProps,
      isBlocking,
      titleAriaId,
      subtitleAriaId,
      isDarkOverlay,
      onDismiss,
      overlay,
      ignoreExternalFocusing,
      x,
      y
    } = this;
    if (!isOpen) return null;
    const mergedLayerProps = { ...DefaultLayerProps,
      ...this.layerProps,
      onLayerDidMount: layerProps && layerProps.onLayerDidMount,
      insertFirst: isModeless,
      className: classNames.layer
    };
    const modalContent = h("div", {
      "class": classNames.main
    }, [dragOptions && isInKeyboardMoveMode && h("div", {
      "class": classNames.keyboardMoveIconContainer
    }, [dragOptions.keyboardMoveIconProps ? h(Icon, _mergeJSXProps([{}, dragOptions.keyboardMoveIconProps])) : h(Icon, {
      "attrs": {
        "iconName": "move"
      },
      "class": classNames.keyboardMoveIcon
    })]), h("div", {
      "ref": "scrollableContent",
      "class": classNames.scrollableContent,
      "attrs": {
        "data-is-scrollable": true
      }
    }, [dragOptions && this.isModalMenuOpen && h(dragOptions.menu, {
      "attrs": {
        "items": [{
          key: 'move',
          text: dragOptions.moveMenuItemText,
          onClick: this.onEnterKeyboardMoveMode
        }, {
          key: 'close',
          text: dragOptions.closeMenuItemText,
          onClick: this.onModalClose
        }],
        "alignTargetEdge": true,
        "coverTarget": true,
        "directionalHint": DirectionalHint.topLeftEdge,
        "directionalHintFixed": true,
        "shouldFocusOnMount": true,
        "target": this.$refs.scrollableContent
      },
      "on": {
        "dismiss": this.onModalContextMenuClose
      }
    }), this.$slots.default])]);

    if (responsiveMode >= ResponsiveMode.small) {
      return h(Layer, _mergeJSXProps([{}, mergedLayerProps]), [h(Popup, {
        "attrs": {
          "role": isModeless || !isBlocking ? 'dialog' : 'alertdialog',
          "aria-modal": !isModeless,
          "ariaLabelledBy": titleAriaId,
          "ariaDescribedBy": subtitleAriaId,
          "shouldRestoreFocus": !ignoreExternalFocusing
        },
        "on": {
          "dismiss": onDismiss
        }
      }, [h("div", {
        "class": classNames.root
      }, [!isModeless && h(Overlay, {
        "attrs": {
          "dark": isDarkOverlay,
          "allowTouchBodyScroll": this.allowTouchBodyScroll
        },
        "on": {
          "click": isBlocking ? undefined : onDismiss
        },
        "props": { ...overlay
        }
      }), dragOptions ? // <DraggableZone
      //   handleSelector={dragOptions.dragHandleSelector || `.${classNames.main.split(' ')[0]}`}
      //   preventDragSelector="button"
      //   onStart={this._onDragStart}
      //   onDragChange={this._onDrag}
      //   onStop={this._onDragStop}
      //   position={{ x: x, y: y }}
      // >
      modalContent // </DraggableZone>
      : modalContent])])]);
    }
  }

};

__decorate([Prop({
  type: Boolean,
  default: false
}), __metadata("design:type", Boolean)], ModalBase.prototype, "isOpen", void 0);

__decorate([Prop({
  type: Boolean,
  default: true
}), __metadata("design:type", Boolean)], ModalBase.prototype, "isDarkOverlay", void 0);

__decorate([Prop({
  type: Function,
  default: null
}), __metadata("design:type", Function)], ModalBase.prototype, "onDismissed", void 0);

__decorate([Prop({
  type: Object,
  default: null
}), __metadata("design:type", Object)], ModalBase.prototype, "layerProps", void 0);

__decorate([Prop({
  type: Object,
  default: null
}), __metadata("design:type", Object)], ModalBase.prototype, "overlay", void 0);

__decorate([Prop({
  type: Boolean,
  default: false
}), __metadata("design:type", Boolean)], ModalBase.prototype, "isBlocking", void 0);

__decorate([Prop({
  type: Boolean,
  default: false
}), __metadata("design:type", Boolean)], ModalBase.prototype, "isModeless", void 0);

__decorate([Prop({
  type: String,
  default: ''
}), __metadata("design:type", String)], ModalBase.prototype, "className", void 0);

__decorate([Prop({
  type: String,
  default: ''
}), __metadata("design:type", String)], ModalBase.prototype, "containerClassName", void 0);

__decorate([Prop({
  type: String,
  default: ''
}), __metadata("design:type", String)], ModalBase.prototype, "scrollableContentClassName", void 0);

__decorate([Prop({
  type: String,
  default: ''
}), __metadata("design:type", String)], ModalBase.prototype, "titleAriaId", void 0);

__decorate([Prop({
  type: String,
  default: ''
}), __metadata("design:type", String)], ModalBase.prototype, "subtitleAriaId", void 0);

__decorate([Prop({
  type: Boolean,
  default: false
}), __metadata("design:type", Boolean)], ModalBase.prototype, "topOffsetFixed", void 0);

__decorate([Prop({
  type: Object,
  default: null
}), __metadata("design:type", Object)], ModalBase.prototype, "dragOptions", void 0);

__decorate([Prop({
  type: Boolean,
  default: false
}), __metadata("design:type", Boolean)], ModalBase.prototype, "allowTouchBodyScroll", void 0);

__decorate([Prop({
  type: Boolean,
  default: false
}), __metadata("design:type", Boolean)], ModalBase.prototype, "ignoreExternalFocusing", void 0);

__decorate([Watch('isOpen'), __metadata("design:type", Function), __metadata("design:paramtypes", [Object]), __metadata("design:returntype", void 0)], ModalBase.prototype, "onIsOpenChanged", null);

ModalBase = __decorate([Component], ModalBase);

export { ModalBase };
