import { __decorate, __metadata } from 'tslib';
import { Prop, Component } from 'vue-property-decorator';
import { classNamesFunction } from '@uifabric-vue/utilities';
import BaseComponent from '../BaseComponent.js';
import _mergeJSXProps from '@vue/babel-helper-vue-jsx-merge-props';
import { Grid } from '../../utilities/grid/Grid.js';
import { ColorPickerGridCell } from './ColorPickerGridCell/ColorPickerGridCell.js';

const getClassNames = classNamesFunction();
let SwatchColorPickerBase = class SwatchColorPickerBase extends BaseComponent {
  get classNames() {
    const {
      theme,
      styles,
      className,
      cellMargin
    } = this;
    return getClassNames(styles, {
      theme,
      className,
      cellMargin
    });
  }

  render() {
    const h = arguments[0];
    const {
      colorCells,
      columnCount,
      cellShape,
      cellWidth,
      cellHeight
    } = this;
    return h(Grid, _mergeJSXProps([{
      "attrs": {
        "items": colorCells,
        "column-count": columnCount
      }
    }, {
      scopedSlots: {
        default: ({
          cell: item
        }) => h(ColorPickerGridCell, {
          "attrs": {
            "color": item.color,
            "circle": cellShape === 'circle',
            "width": cellWidth,
            "height": cellHeight
          }
        })
      }
    }]));
  }

};

__decorate([Prop({
  default: 10
}), __metadata("design:type", Number)], SwatchColorPickerBase.prototype, "cellMargin", void 0);

__decorate([Prop({
  type: Array,
  default: () => []
}), __metadata("design:type", Array)], SwatchColorPickerBase.prototype, "colorCells", void 0);

__decorate([Prop({
  type: Number
}), __metadata("design:type", Number)], SwatchColorPickerBase.prototype, "columnCount", void 0);

__decorate([Prop({
  type: String,
  default: 'circle'
}), __metadata("design:type", String)], SwatchColorPickerBase.prototype, "cellShape", void 0);

__decorate([Prop({
  type: Number
}), __metadata("design:type", Number)], SwatchColorPickerBase.prototype, "cellHeight", void 0);

__decorate([Prop({
  type: Number
}), __metadata("design:type", Number)], SwatchColorPickerBase.prototype, "cellWidth", void 0);

SwatchColorPickerBase = __decorate([Component({
  components: {
    Grid,
    ColorPickerGridCell
  },
  inheritAttrs: false
})], SwatchColorPickerBase);

export { SwatchColorPickerBase };
